@@ -48,6 +48,8 @@
 #include "prprf.h"
 #include "mimeobj.h"
 #include "enigmail.h"
+#include "nsIMimeConverter.h"
+
 
 typedef enum mime_encoding {
   mime_Base64, mime_QuotedPrintable, mime_uuencode, mime_yencode
@@ -71,7 +73,8 @@ struct MimeDecoderData {
 
   MimeObject *objectToDecode; // might be null, only used for QP currently
   /* Where to write the decoded data */
-  nsresult (*write_buffer) (const char *buf, PRInt32 size, void *closure);
+  //nsresult (*write_buffer) (const char *buf, PRInt32 size, void *closure);
+  MimeConverterOutputCallback write_buffer;
   void *closure;
 };
 
@@ -785,7 +788,7 @@ MimeDecoderDestroy (MimeDecoderData *data, EMBool abort_p)
 
 static MimeDecoderData *
 mime_decoder_init (mime_encoding which,
-           nsresult (*output_fn) (const char *, PRInt32, void *),
+           MimeConverterOutputCallback output_fn,
            void *closure)
 {
   MimeDecoderData *data = PR_NEW(MimeDecoderData);
@@ -801,14 +804,14 @@ mime_decoder_init (mime_encoding which,
 }
 
 MimeDecoderData *
-MimeB64DecoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeB64DecoderInit (MimeConverterOutputCallback output_fn,
           void *closure)
 {
   return mime_decoder_init (mime_Base64, output_fn, closure);
 }
 
 MimeDecoderData *
-MimeQPDecoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeQPDecoderInit (MimeConverterOutputCallback output_fn,
            void *closure, MimeObject *object)
 {
   MimeDecoderData *retData = mime_decoder_init (mime_QuotedPrintable, output_fn, closure);
@@ -818,14 +821,14 @@ MimeQPDecoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
 }
 
 MimeDecoderData *
-MimeUUDecoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeUUDecoderInit (MimeConverterOutputCallback output_fn,
            void *closure)
 {
   return mime_decoder_init (mime_uuencode, output_fn, closure);
 }
 
 MimeDecoderData *
-MimeYDecoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeYDecoderInit (MimeConverterOutputCallback output_fn,
            void *closure)
 {
   return mime_decoder_init (mime_yencode, output_fn, closure);
@@ -873,7 +876,7 @@ struct MimeEncoderData {
   char *filename; /* filename for use with uuencoding */
 
   /* Where to write the encoded data */
-  nsresult (*write_buffer) (const char *buf, PRInt32 size, void *closure);
+  MimeConverterOutputCallback write_buffer;
   void *closure;
 };
 
@@ -974,7 +977,7 @@ mime_uuencode_buffer(MimeEncoderData *data,
   return 0;
 }
 
-int
+void
 mime_uuencode_finish(MimeEncoderData *data)
 {
   int i;
@@ -997,7 +1000,7 @@ mime_uuencode_finish(MimeEncoderData *data)
   }
 
   /* Write 'end' on a line by itself. */
-  return data->write_buffer(endStr, strlen(endStr), data->closure);
+  data->write_buffer(endStr, strlen(endStr), data->closure);
 }
 
 #undef ENC
@@ -1309,7 +1312,7 @@ MimeEncoderDestroy (MimeEncoderData *data, EMBool abort_p)
 
 static MimeEncoderData *
 mime_encoder_init (mime_encoding which,
-           nsresult (*output_fn) (const char *, PRInt32, void *),
+           MimeConverterOutputCallback output_fn,
            void *closure)
 {
   MimeEncoderData *data = PR_NEW(MimeEncoderData);
@@ -1322,14 +1325,14 @@ mime_encoder_init (mime_encoding which,
 }
 
 MimeEncoderData *
-MimeB64EncoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeB64EncoderInit (MimeConverterOutputCallback output_fn,
           void *closure)
 {
   return mime_encoder_init (mime_Base64, output_fn, closure);
 }
 
 MimeEncoderData *
-MimeQPEncoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
+MimeQPEncoderInit (MimeConverterOutputCallback output_fn,
            void *closure)
 {
   return mime_encoder_init (mime_QuotedPrintable, output_fn, closure);
@@ -1337,7 +1340,7 @@ MimeQPEncoderInit (nsresult (*output_fn) (const char *, PRInt32, void *),
 
 MimeEncoderData *
 MimeUUEncoderInit (char *filename,
-          nsresult (*output_fn) (const char *, PRInt32, void *),
+          MimeConverterOutputCallback output_fn,
           void *closure)
 {
   MimeEncoderData *enc = mime_encoder_init (mime_uuencode, output_fn, closure);
